Forms
=====

.. contents::

SimpleTransactionForm
---------------------

.. autoclass:: hordak.forms.SimpleTransactionForm

TransactionForm
---------------

.. autoclass:: hordak.forms.TransactionForm

LegForm
-------

.. autoclass:: hordak.forms.LegForm

LegFormSet
----------

A formset which can be used to display multiple :class:`Leg forms <hordak.forms.LegForm>`.
Useful when creating transactions.
